@@ -1,7 +1,12 @@
-from igem_wikisync.files import HTMLfile, CSSfile, JSfile, OtherFile
-import pytest
 from datetime import date
 
+import pytest
+
+from igem_wikisync.files import CSSfile
+from igem_wikisync.files import HTMLfile
+from igem_wikisync.files import JSfile
+from igem_wikisync.files import OtherFile
+
 
 @pytest.fixture
 def config():
