@@ -1,6 +1,9 @@
-from igem_wikisync.path import is_relative, resolve_relative_path, iGEM_URL
 from datetime import date
 
+from igem_wikisync.path import iGEM_URL
+from igem_wikisync.path import is_relative
+from igem_wikisync.path import resolve_relative_path
+
 
 def test_is_relative():
 
@@ -46,7 +49,8 @@ def test_iGEM_URL():
         'src_dir': 'tests/data',
         'build_dir': 'tests/build',
         'team': 'BITSPilani-Goa_India',
-        'year': str(date.today().year)
+        'year': str(date.today().year),
+        'silence_warnings': False
     }
 
     upload_map = {
